# chercher-plugin-yt

Chercher plugin that adds support for YouTube videos.

## Installation

```bash
uv tool install --with chercher-plugin-yt chercher
```

## Settings

> [!NOTE]
> If you plugin needs additional settings, add the instructions here.

## Development

> [!NOTE]
> TODO
